==> sage-0.7.7-2005-10-04-src.tar.gz: sage-0.7.7-2005-10-04/doc/tut/images.pl <==
# LaTeX2HTML 2002-2-1 (1.71)
# Associate images original text with physical files.


$key = q/mathbf{Z}slashNmathbf{Z}toR;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="100" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="$\mathbf{Z}/N\mathbf{Z}\to R$">|; 

$key = q/m^{th};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="34" HEIGHT="19" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="$m^{th}$">|; 

$key = q/leq10000;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="72" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img39.png"
 ALT="$\leq 10000$">|; 

$key = q/m;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="21" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img47.png"
 ALT="$m$">|; 

$key = q/xinmathbf{Z}slashNmathbf{Z};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="90" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="$x\in\mathbf{Z}/N\mathbf{Z}$">|; 

$key = q/(n-1)^{st};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="75" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$(n-1)^{st}$">|; 

$key = q/a_2;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img25.png"
 ALT="$a_2$">|; 

$key = q/sin(2slash3)=0;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="105" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img49.png"
 ALT="$\sin(2/3)=0$">|; 

$key = q/-1;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="29" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$-1$">|; 

$key = q/E:y^2+y=x^3-x;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="169" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img34.png"
 ALT="$E: y^2 + y = x^3 - x$">|; 

$key = q/2;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="$2$">|; 

$key = q/mslashn;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="42" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img48.png"
 ALT="$m/n$">|; 

$key = q/k^{th};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="28" HEIGHT="19" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="$k^{th}$">|; 

$key = q/a_3;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img26.png"
 ALT="$a_3$">|; 

$key = q/sum_{n=0}^inftya_nq^n;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="88" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img38.png"
 ALT="$\sum_{n=0}^\infty a_nq^n$">|; 

$key = q/mathbf{Z}slashpmathbf{Z};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="50" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img46.png"
 ALT="$\mathbf{Z}/p\mathbf{Z}$">|; 

$key = q/a_1=a_2=a_3=0;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="142" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img31.png"
 ALT="$a_1=a_2=a_3=0$">|; 

$key = q/a_1;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="$a_1$">|; 

$key = q/5;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img32.png"
 ALT="$5$">|; 

$key = q/0;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="$0$">|; 

$key = q/to;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="24" HEIGHT="18" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$\to$">|; 

$key = q/y^2+a_1xy+a_3y=x^3+a_2x^2+a_4x+a_6;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="326" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img29.png"
 ALT="$y^2+a_1xy+a_3y=x^3+a_2x^2+a_4x+a_6$">|; 

$key = q/S;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="17" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img45.png"
 ALT="$S$">|; 

$key = q/phi;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="$\phi$">|; 

$key = q/L;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="17" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img37.png"
 ALT="$L$">|; 

$key = q/Gal(mathbf{Q}(zeta_n)slashmathbf{Q});MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="123" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="$Gal(\mathbf{Q}(\zeta_n)/\mathbf{Q})$">|; 

$key = q/mathbf{Z}slashNmathbf{Z};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="56" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="$\mathbf{Z}/N\mathbf{Z}$">|; 

$key = q/V;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$V$">|; 

$key = q/1;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img41.png"
 ALT="$1$">|; 

$key = q/x=y=0;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="85" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img33.png"
 ALT="$x=y=0$">|; 

$key = q/y^2=x^3+infty;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="108" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="$y^2=x^3+\infty$">|; 

$key = q/V=mathbf{Q}^3;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="69" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="$V=\mathbf{Q}^3$">|; 

$key = q/12;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img42.png"
 ALT="$12$">|; 

$key = q/R;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="$R$">|; 

$key = q/gcd(N,x)>1;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="117" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="$\gcd(N,x)&gt;1$">|; 

$key = q/a_i;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img30.png"
 ALT="$a_i$">|; 

$key = q/A;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="$A$">|; 

$key = q/Gamma_1(N);MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="55" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img44.png"
 ALT="$\Gamma_1(N)$">|; 

$key = q/Gamma_0(N);MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="55" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img43.png"
 ALT="$\Gamma_0(N)$">|; 

$key = q/a_n;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img36.png"
 ALT="$a_n$">|; 

$key = q/n;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="$n$">|; 

$key = q/zeta;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="$\zeta$">|; 

$key = q/a_4;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img27.png"
 ALT="$a_4$">|; 

$key = q/120000;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="61" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img40.png"
 ALT="$120000$">|; 

$key = q/mathbf{Q};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="21" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$\mathbf{Q}$">|; 

$key = q/mathbf{Q}(i);MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="42" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="$\mathbf{Q}(i)$">|; 

$key = q/a_6;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img28.png"
 ALT="$a_6$">|; 

$key = q/j;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img35.png"
 ALT="$j$">|; 

$key = q/{displaymath}(mathbf{Z}slashNmathbf{Z})^*toR^*,{displaymath};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="127" HEIGHT="33" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="\begin{displaymath}
(\mathbf{Z}/N\mathbf{Z})^* \to R^*,
\end{displaymath}">|; 

1;

==> sage-0.8.2-2005-10-22-src.tar.gz: sage-0.8.2-2005-10-22/doc/tut/images.pl <==
# LaTeX2HTML 2002-2-1 (1.71)
# Associate images original text with physical files.


$key = q/mathbf{Z}slashNmathbf{Z}toR;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="100" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="$\mathbf{Z}/N\mathbf{Z}\to R$">|; 

$key = q/leq10000;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="72" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img42.png"
 ALT="$\leq 10000$">|; 

$key = q/m;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="21" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="$m$">|; 

$key = q/xinmathbf{Z}slashNmathbf{Z};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="90" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="$x\in\mathbf{Z}/N\mathbf{Z}$">|; 

$key = q/a_2;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="$a_2$">|; 

$key = q/sin(2slash3)=0;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="105" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img52.png"
 ALT="$\sin(2/3)=0$">|; 

$key = q/F;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img37.png"
 ALT="$ F$">|; 

$key = q/-1;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="29" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="$-1$">|; 

$key = q/2;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="$2$">|; 

$key = q/(n-1);MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="63" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="$ (n-1)$">|; 

$key = q/y^2+y=x^3-x;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="132" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img36.png"
 ALT="$ y^2 +
y = x^3 - x$">|; 

$key = q/mslashn;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="42" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img51.png"
 ALT="$m/n$">|; 

$key = q/k;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="15" HEIGHT="17" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="$ k$">|; 

$key = q/a_3;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img25.png"
 ALT="$a_3$">|; 

$key = q/displaystyley^2+a_1xy+a_3y=x^3+a_2x^2+a_4x+a_6,;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="332" HEIGHT="41" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img28.png"
 ALT="$\displaystyle y^2+a_1xy+a_3y=x^3+a_2x^2+a_4x+a_6,$">|; 

$key = q/sum_{n=0}^inftya_nq^n;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="88" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img40.png"
 ALT="$\sum_{n=0}^\infty a_nq^n$">|; 

$key = q/mathbf{Z}slashpmathbf{Z};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="50" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img50.png"
 ALT="$\mathbf{Z}/p\mathbf{Z}$">|; 

$key = q/a_1=a_2=a_3=0;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="142" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img31.png"
 ALT="$a_1=a_2=a_3=0$">|; 

$key = q/E;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img35.png"
 ALT="$ E$">|; 

$key = q/a_1;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="$a_1$">|; 

$key = q/5;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img33.png"
 ALT="$5$">|; 

$key = q/mathbf{F}_7[[T]];MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="60" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="$ \mathbf{F}_7[[T]]$">|; 

$key = q/S;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="17" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img49.png"
 ALT="$S$">|; 

$key = q/phi;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="$\phi$">|; 

$key = q/L;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="17" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img39.png"
 ALT="$L$">|; 

$key = q/Gal(mathbf{Q}(zeta_n)slashmathbf{Q});MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="123" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="$Gal(\mathbf{Q}(\zeta_n)/\mathbf{Q})$">|; 

$key = q/mathbf{Z}slashNmathbf{Z};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="56" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$\mathbf{Z}/N\mathbf{Z}$">|; 

$key = q/nleq10^5;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="68" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img41.png"
 ALT="$ n\leq 10^5$">|; 

$key = q/displaystyle(mathbf{Z}slashNmathbf{Z})^*toR^*,;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="135" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="$\displaystyle (\mathbf{Z}/N\mathbf{Z})^* \to R^*,
$">|; 

$key = q/mathbf{Z};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="18" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img30.png"
 ALT="$ \mathbf{Z}$">|; 

$key = q/V;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$V$">|; 

$key = q/1;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img44.png"
 ALT="$1$">|; 

$key = q/_{3times3}(mathbf{Q});MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="60" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img48.png"
 ALT="$ _{3\times 3}(\mathbf{Q})$">|; 

$key = q/V=mathbf{Q}^3;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="69" HEIGHT="39" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="$V=\mathbf{Q}^3$">|; 

$key = q/12;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img45.png"
 ALT="$12$">|; 

$key = q/R;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="$R$">|; 

$key = q/gcd(N,x)>1;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="117" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="$\gcd(N,x)&gt;1$">|; 

$key = q/a_i;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="20" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img29.png"
 ALT="$a_i$">|; 

$key = q/(0,0;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="39" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img34.png"
 ALT="$ (0,0$">|; 

$key = q/A;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$A$">|; 

$key = q/Gamma_1(N);MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="55" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img47.png"
 ALT="$\Gamma_1(N)$">|; 

$key = q/Gamma_0(N);MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="55" HEIGHT="38" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img46.png"
 ALT="$\Gamma_0(N)$">|; 

$key = q/a_n;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img38.png"
 ALT="$a_n$">|; 

$key = q/n;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="$n$">|; 

$key = q/zeta;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="14" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="$\zeta$">|; 

$key = q/a_4;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img26.png"
 ALT="$a_4$">|; 

$key = q/120000;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="61" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img43.png"
 ALT="$120000$">|; 

$key = q/mathbf{Q};MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="21" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="$\mathbf{Q}$">|; 

$key = q/mathbf{Q}(i);MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="42" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="$\mathbf{Q}(i)$">|; 

$key = q/mathbf{F}_7((T));MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="68" HEIGHT="37" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="$ \mathbf{F}_7((T))$">|; 

$key = q/a_6;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="22" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img27.png"
 ALT="$a_6$">|; 

$key = q/j;MSF=1.6;AAT/;
$cached_env_img{$key} = q|<IMG
 WIDTH="13" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img32.png"
 ALT="$j$">|; 

1;
